==> matrix_sdk-0.30.0.tar.gz: lib/matrix_sdk.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

export 'src/homeserver.dart';
export 'src/updater.dart';
export 'src/user.dart';
export 'src/my_user.dart';
export 'src/exception.dart';
export 'src/identifier.dart';
export 'src/device.dart';

export 'src/loadables.dart';

export 'src/room/room.dart';

export 'src/event/event.dart';

export 'src/notifications/pusher.dart';
export 'src/notifications/pushers.dart';

export 'src/event/room/room_event.dart';

export 'src/event/room/message_event.dart';
export 'src/event/room/redaction_event.dart';

export 'src/event/room/state/state_event.dart';
export 'src/event/room/state/room_creation_event.dart';
export 'src/event/room/state/room_avatar_change_event.dart';
export 'src/event/room/state/member_change_event.dart';
export 'src/event/room/state/room_name_change_event.dart';
export 'src/event/room/state/room_upgrade_event.dart';
export 'src/event/room/state/topic_change_event.dart';
export 'src/event/room/state/power_levels_change_event.dart';
export 'src/event/room/state/join_rules_change_event.dart';
export 'src/event/room/state/aliases_change_event.dart';

export 'src/room/member/membership.dart';
export 'src/room/member/member.dart';
export 'src/room/member/member_timeline.dart';

export 'src/store/store.dart';
export 'src/store/moor/moor_store.dart';

export 'src/util/mxc_url.dart' show MatrixUrl;

export 'src/encryption/olm.dart';
export 'src/encryption/account.dart';

==> matrix_sdk-0.32.0.tar.gz: lib/matrix_sdk.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

export 'src/homeserver.dart';
export 'src/updater/updater.dart';
export 'src/user.dart';
export 'src/my_user.dart';
export 'src/exception.dart';
export 'src/identifier.dart';
export 'src/device.dart';

export 'src/public_rooms.dart';

export 'src/room/room.dart';

export 'src/room/timeline.dart';

export 'src/event/event.dart';

export 'src/notifications/pusher.dart';
export 'src/notifications/pushers.dart';

export 'src/event/room/room_event.dart';

export 'src/event/room/message_event.dart';
export 'src/event/room/redaction_event.dart';

export 'src/event/room/state/state_event.dart';
export 'src/event/room/state/room_creation_event.dart';
export 'src/event/room/state/room_avatar_change_event.dart';
export 'src/event/room/state/member_change_event.dart';
export 'src/event/room/state/room_name_change_event.dart';
export 'src/event/room/state/room_upgrade_event.dart';
export 'src/event/room/state/topic_change_event.dart';
export 'src/event/room/state/power_levels_change_event.dart';
export 'src/event/room/state/join_rules_change_event.dart';

export 'src/room/member/membership.dart';
export 'src/room/member/member.dart';
export 'src/room/member/member_timeline.dart';

export 'src/store/store.dart';
export 'src/store/moor/moor_store.dart';

export 'src/util/mxc_url.dart' show MatrixUrl;

export 'src/encryption/olm.dart';
export 'src/encryption/account.dart';
